#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2015-2016, Mirantis, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.


from trsync.api import TRSyncApi
from trsync.cli.commands.base import TRSyncCmd


class GetTargetCmd(TRSyncCmd):
    def get_description(self):
        return "Evaluate the target for specified symlink "\
            "(optional recursively)"

    def get_parser(self, prog_name):
        parser = super(GetTargetCmd, self).get_parser(prog_name)

        parser.add_argument('symlink_url',
                            help='Symlink url to resolve (supported by rsync)')
        parser.add_argument('-r', '--recursive',
                            action='store_true',
                            required=False,
                            default=False,
                            help='It specified, the symlink will be resolved '
                            'recursively (if the symlink targeted to other '
                            'symlinks tree - they will be resolved too). '
                            'Disabled by default.')
        return parser

    def take_action(self, parsed_args):
        args = vars(parsed_args)
        target = TRSyncApi().get_target(args['symlink_url'],
                                        recursive=args['recursive'])
        print(target)
