#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2015-2016, Mirantis, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.


import sys
from trsync.api import TRSyncApi
from trsync.cli.commands.base import TRSyncCmd


class RemoveCmd(TRSyncCmd):

    def get_description(self):
        return "remove all specified paths from several DST recursively"

    def get_parser(self, prog_name):
        parser = super(RemoveCmd, self).get_parser(prog_name)

        parser.add_argument('path',
                            nargs='+',
                            help='Path to remove')
        parser.add_argument('-d', '--dest',
                            nargs='+',
                            required=True,
                            help='Destination rsync url')
        parser.add_argument('--extra',
                            required=False,
                            default='',
                            help='String with additional rsync parameters. '
                            'For example it may be "\--dry-run '
                            '--any-rsync-option". Use "\\" to disable '
                            'argparse to parse extra value.')
        return parser

    def take_action(self, parsed_args):
        args = vars(parsed_args)

        results = TRSyncApi().remove(
            args['dest'], args['path'],
            rsync_extra_params=self._extra(args['extra'])
        )
        exitcode = self._debrief(results)
        sys.exit(exitcode)
